@@ -67,7 +67,7 @@ async def send_results_to_server(
         await client.execute(
             query="""
                 mutation(
-                    $systemId: [TransactionInput!]!
+                    $systemId: String!
                     $transactions: [TransactionInput!]!
                 ) {
                     putTransaction(
